HttpClientParams<DTO, DQO> class

Constructors

HttpClientParams({required String path, required String method, DTO? body, DQO? query, Map<String, dynamic>? options})

Properties

body → DTO?
final
hashCode int
The hash code for this object.
no setterinherited
method String
final
options Map<String, dynamic>?
final
path String
final
query → DQO?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited