HttpService class

Constructors

HttpService({required Dio dio, required String token})

Properties

dio ↔ Dio
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolver<T>(Future<Response> fn) Future<HttpClientResolverDTO<T>>
sendRequest(HttpClientParams params) Future<HttpClientResolverDTO>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

apiEndpoint → const String