CalendarEventOptions class

Constructors

CalendarEventOptions({required String title, required DateTime startDate, required DateTime endDate, String? description, String? location, String? url, String? organizer})

Properties

description String?
final
endDate DateTime
final
hashCode int
The hash code for this object.
no setterinherited
location String?
final
organizer String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate DateTime
final
title String
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited