SendMailOptions class

Constructors

SendMailOptions({required String subject, required MailSender sender, required dynamic recipients, String? message, MailTemplate? template, List<MailAttachment?>? attachments, CalendarEventOptions? calendarEvent, ResponseAddress? responseAddress})

Properties

attachments List<MailAttachment?>?
final
calendarEvent CalendarEventOptions?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
recipients → dynamic
final
responseAddress ResponseAddress?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender MailSender
final
subject String
final
template MailTemplate?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited