SendApi class

Constructors

SendApi(HttpService httpService)

Properties

hashCode int
The hash code for this object.
no setterinherited
httpService HttpService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendCalendarEvent(CalendarEventOptions? event) Map<String, String>
appendRecipients(dynamic recipients) Map<String, String>
appendResponseAddress(ResponseAddress? address) Map<String, String>
appendTemplate(MailTemplate? template) Map<String, String>
getFormBody(SendMailOptions options) Future<FormData>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMail(SendMailOptions options) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited